==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/text/l10n/he.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "קובץ טקסט חדש",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
    "Nextcloud Text" : "טקסט Nextcloud",
    "text document" : "מסמך טקסט",
    "Readme" : "הסבר",
    "Text" : "טקסט",
    "📝 Collaborative document editing" : "📝 עריכת מסמכים שיתופית",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 עריכת מסמכים שיתופית!**\n\n- **📝 כתיבה ממוקדת:** בלי הפרעות, רק כלי העיצוב הנחוצים.\n- **🙋 לעבוד ביחד:** שיתוף פעולה עם חברים ועמיתים לעבודה, בין אם הם משתמשים ב־Nextcloud או לא!\n- **💾 תקן פתוח:** הקבצים נשמרים בתור [Markdown](https://en.wikipedia.org/wiki/Markdown), כך שניתן לערוך אותם בכל יישומון טקסט אחר בנוסף.\n- **✊ יסודות יציבים:** אנו משתמשים ב־[🐈 tiptap](https://tiptap.scrumpy.io) שמבוסס על [🦉 ProseMirror](https://prosemirror.net) – תודה ענקית להם!",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Use the saved version" : "להשתמש בגרסה השמורה",
    "Document idle for {timeout} minutes, click to continue editing" : "מסמך אינו פעיל למשך {timeout} דקות, לחץ כדי להמשיך בעריכה",
    "Reconnect" : "התחבר מחדש",
    "The document has been changed outside of the editor. The changes cannot be applied." : "המסמך נערך מחוץ לעורך. לא ניתן להחיל את השינויים.",
    "File could not be loaded. Please check your internet connection." : "לא ניתן לטעון את הקובץ. נא לבדוק את מצב החיבור שלך לאינטרנט.",
    "Edit guest name" : "עריכת שם אורח",
    "Guest" : "אורח/ת",
    "Save guest name" : "שמירת שם אורח",
    "guest" : "אורח",
    "Saving …" : "מתבצעת שמירה…",
    "Saved" : "נשמרה",
    "Last saved {lastSaved}" : "שמירה אחרונה: {lastSaved}",
    "Unsaved changes" : "שינויים שלא נשמרו",
    "Formatting help" : "עזרה בסידור בתבנית",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Bold" : "מודגש",
    "Italic" : "נטוי",
    "Strikethrough" : "קו חוצה",
    "Shift" : "הזזה",
    "Heading 1" : "כותרת 1",
    "Heading 6" : "כותרת 6",
    "Unordered list" : "רשימה בלתי ממוינת",
    "Ordered list" : "רשימה ממוינת",
    "Blockquote" : "מקטע ציטוט",
    "Code block" : "מקטע קוד",
    "Update link" : "עדכן את הקישור",
    "Unsupported image type" : "סוג התמונה לא נתמך",
    "Show rich workspaces" : "הצגת סביבות עבודה עשירות",
    "Add notes, lists or links …" : "ניתן להוסיף הערות, רשימות או קישורים…",
    "Undo" : "ביטול",
    "Redo" : "שחזור",
    "Headings" : "כותרות",
    "Heading 2" : "כותרת 2",
    "Heading 3" : "כותרת 3",
    "Heading 4" : "כותרת 4",
    "Heading 5" : "כותרת 5",
    "Info" : "פרטים",
    "Success" : "הצלחה",
    "Warning" : "אזהרה",
    "Insert attachment" : "הוספת קובץ מצורף",
    "Command" : "פקודה",
    "Control" : "שליטה",
    "Edit" : "עריכה",
    "New text document" : "מסמך טקסט חדש",
    "Enter your name so other users can see who is editing" : "נא למלא את שמך כדי שמשתמשים אחרים יוכלו לראות מי עורך",
    "Insert image" : "הוספת תמונה",
    "Insert an image" : "הוספת תמונה",
    "Link file" : "קישור לקובץ",
    "Select file to link to" : "לבחור קובץ לקשר אליו",
    "Currently active users:" : "משתמשים פעילים עכשיו:",
    "_and %n other editor_::_and %n other editors_" : ["ועורך (%n) נוסף","ו־%n עורכים נוספים","ו־%n עורכים נוספים","ו־%n עורכים נוספים"],
    "ToDo list" : "רשימת מטלות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-26.0.0.tar.bz2: nextcloud/apps/text/l10n/he.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "קובץ טקסט חדש",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מההנחיה upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שצוינה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "לא הועלה קובץ",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
    "Nextcloud Text" : "טקסט Nextcloud",
    "text document" : "מסמך טקסט",
    "Readme" : "הסבר",
    "Text" : "טקסט",
    "📝 Collaborative document editing" : "📝 עריכת מסמכים שיתופית",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 עריכת מסמכים שיתופית!**\n\n- **📝 כתיבה ממוקדת:** בלי הפרעות, רק כלי העיצוב הנחוצים.\n- **🙋 לעבוד ביחד:** שיתוף פעולה עם חברים ועמיתים לעבודה, בין אם הם משתמשים ב־Nextcloud או לא!\n- **💾 תקן פתוח:** הקבצים נשמרים בתור [Markdown](https://en.wikipedia.org/wiki/Markdown), כך שניתן לערוך אותם בכל יישומון טקסט אחר בנוסף.\n- **✊ יסודות יציבים:** אנו משתמשים ב־[🐈 tiptap](https://tiptap.scrumpy.io) שמבוסס על [🦉 ProseMirror](https://prosemirror.net) – תודה ענקית להם!",
    "Use current version" : "להשתמש בגרסה הנוכחית",
    "Use the saved version" : "להשתמש בגרסה השמורה",
    "Document idle for {timeout} minutes, click to continue editing" : "מסמך אינו פעיל למשך {timeout} דקות, לחץ כדי להמשיך בעריכה",
    "Reconnect" : "התחבר מחדש",
    "The document has been changed outside of the editor. The changes cannot be applied." : "המסמך נערך מחוץ לעורך. לא ניתן להחיל את השינויים.",
    "File could not be loaded. Please check your internet connection." : "לא ניתן לטעון את הקובץ. נא לבדוק את מצב החיבור שלך לאינטרנט.",
    "This file is opened read-only as it is currently locked by {user}." : "הקובץ נפתח לקריאה בלבד מפני שהוא כרגע נעול על ידי [user].",
    "Edit guest name" : "עריכת שם אורח",
    "Guest" : "אורח/ת",
    "Save guest name" : "שמירת שם אורח",
    "guest" : "אורח",
    "Offline" : "בלתי מקוון",
    "Saving …" : "מתבצעת שמירה…",
    "Saved" : "נשמרה",
    "Unsaved changes" : "שינויים שלא נשמרו",
    "Formatting help" : "עזרה בסידור בתבנית",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Shift" : "הזזה",
    "Bold" : "מודגש",
    "Italic" : "נטוי",
    "Strikethrough" : "קו חוצה",
    "Heading 1" : "כותרת 1",
    "Heading 6" : "כותרת 6",
    "Unordered list" : "רשימה בלתי ממוינת",
    "Ordered list" : "רשימה ממוינת",
    "Blockquote" : "מקטע ציטוט",
    "Code block" : "מקטע קוד",
    "Update link" : "עדכן את הקישור",
    "Translate" : "תרגום",
    "Replace" : "החלפה",
    "Unsupported image type" : "סוג התמונה לא נתמך",
    "Show rich workspaces" : "הצגת סביבות עבודה עשירות",
    "Undo" : "ביטול",
    "Redo" : "שחזור",
    "Headings" : "כותרות",
    "Heading 2" : "כותרת 2",
    "Heading 3" : "כותרת 3",
    "Heading 4" : "כותרת 4",
    "Heading 5" : "כותרת 5",
    "Info" : "פרטים",
    "Success" : "הצלחה",
    "Warning" : "אזהרה",
    "Insert attachment" : "הוספת קובץ מצורף",
    "Command" : "פקודה",
    "Control" : "שליטה",
    "Add notes, lists or links …" : "ניתן להוסיף הערות, רשימות או קישורים…",
    "Edit" : "עריכה",
    "Last saved {lastSaved}" : "שמירה אחרונה: {lastSaved}",
    "Enter your name so other users can see who is editing" : "נא למלא את שמך כדי שמשתמשים אחרים יוכלו לראות מי עורך",
    "Insert an image" : "הוספת תמונה",
    "Link file" : "קישור לקובץ",
    "Select file to link to" : "לבחור קובץ לקשר אליו",
    "ToDo list" : "רשימת מטלות",
    "Insert image" : "הוספת תמונה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
